==> affyPara_1.12.0.zip: affyPara/doc/affyPara.R <==
###################################################
### chunk number 1: 
###################################################
#line 59 "affyPara.Rnw"
library(affyPara)


###################################################
### chunk number 2: 
###################################################
#line 117 "affyPara.Rnw"
library(affyPara)


###################################################
### chunk number 3: 
###################################################
#line 122 "affyPara.Rnw"
library(affydata)
data(Dilution)
Dilution


###################################################
### chunk number 4: 
###################################################
#line 139 "affyPara.Rnw"
cl <- makeCluster(4, type='SOCK')


###################################################
### chunk number 5: 
###################################################
#line 147 "affyPara.Rnw"
stopCluster(cl)


###################################################
### chunk number 6: 
###################################################
#line 150 "affyPara.Rnw"
cl <- makeCluster(2, type='SOCK')


###################################################
### chunk number 7:  eval=FALSE
###################################################
## #line 177 "affyPara.Rnw"
## AffyBatch <- ReadAffy()


###################################################
### chunk number 8: 
###################################################
#line 211 "affyPara.Rnw"
bgcorrect.methods()


###################################################
### chunk number 9: affyBatchBGC
###################################################
#line 219 "affyPara.Rnw"
affyBatchBGC <- bgCorrectPara(Dilution,
				method="rma", verbose=TRUE)


###################################################
### chunk number 10: affyBatchBGCfiles eval=FALSE
###################################################
## #line 227 "affyPara.Rnw"
## files <- list.celfiles(full.names=TRUE)
## affyBatchGBC <- bgCorrectPara(files, 
## 				method="rma", cluster=cl)


###################################################
### chunk number 11: affyBatchNORM
###################################################
#line 261 "affyPara.Rnw"
affyBatchNORM <- normalizeAffyBatchQuantilesPara(
		Dilution, type = "pmonly", verbose=TRUE)


###################################################
### chunk number 12: affyBatchGBCfiles eval=FALSE
###################################################
## #line 268 "affyPara.Rnw"
## files <- list.celfiles(full.names=TRUE)
## affyBatchNORM <- normalizeAffyBatchQuantilesPara(
## 		files, type = "pmonly")


###################################################
### chunk number 13: 
###################################################
#line 290 "affyPara.Rnw"
express.summary.stat.methods()
pmcorrect.methods()


###################################################
### chunk number 14: computeExprSetPara eval=FALSE
###################################################
## #line 299 "affyPara.Rnw"
## esset <- computeExprSetPara(
## 	Dilution,
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 15: computeExprSetParafiles eval=FALSE
###################################################
## #line 308 "affyPara.Rnw"
## files <- list.celfiles(full.names=TRUE)
## esset <- normalizeAffyBatchQuantilesPara(
## 	files, 
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 16: preproPara eval=FALSE
###################################################
## #line 334 "affyPara.Rnw"
## esset <- preproPara(
## 	Dilution, 
## 	bgcorrect = TRUE, bgcorrect.method = "rma",
## 	normalize = TRUE, normalize.method = "quantil",
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 17: preproParafiles eval=FALSE
###################################################
## #line 348 "affyPara.Rnw"
## files <- list.celfiles(full.names=TRUE)
## esset <- preproPara(
## 	files, 
## 	bgcorrect = TRUE, bgcorrect.method = "rma",
## 	normalize = TRUE, normalize.method = "quantil",
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 18: rmaPara eval=FALSE
###################################################
## #line 370 "affyPara.Rnw"
## esset <- rmaPara(Dilution)


###################################################
### chunk number 19: rmaParaFiles eval=FALSE
###################################################
## #line 378 "affyPara.Rnw"
## files <- list.celfiles(full.names=TRUE)
## esset <- rmaPara(files)


###################################################
### chunk number 20: qc eval=FALSE
###################################################
## #line 400 "affyPara.Rnw"
## boxplotPara(Dilution)
## MAplotPara(Dilution)


###################################################
### chunk number 21: distributeFiles eval=FALSE
###################################################
## #line 417 "affyPara.Rnw"
## path <- "tmp/CELfiles" # path at local computer system (master)
## files <- list.files(path,full.names=TRUE)
## distList <- distributeFiles(CELfiles, protocol="RCP")
## eset <- rmaPara(distList$CELfiles)


###################################################
### chunk number 22: removeDistributedFiles eval=FALSE
###################################################
## #line 430 "affyPara.Rnw"
## removeDistributedFiles("/usr1/tmp/CELfiles")


###################################################
### chunk number 23: identical_bgc
###################################################
#line 449 "affyPara.Rnw"
affybatch1 <- bg.correct(Dilution,
		method="rma") 
 affybatch2 <- bgCorrectPara(Dilution,
		method="rma")
identical(exprs(affybatch1),exprs(affybatch2))
all.equal(exprs(affybatch1),exprs(affybatch2))


###################################################
### chunk number 24: identical_loess eval=FALSE
###################################################
## #line 464 "affyPara.Rnw"
## set.seed(1234)
## affybatch1 <- normalize.AffyBatch.loess(Dilution)
## set.seed(1234)
## affybatch2 <- normalizeAffyBatchLoessPara(Dilution, verbose=TRUE) 
## identical(exprs(affybatch1),exprs(affybatch2))


###################################################
### chunk number 25: 
###################################################
#line 505 "affyPara.Rnw"
stopCluster()

==> affyPara_1.18.0.zip: affyPara/doc/affyPara.R <==
### R code from vignette source 'affyPara.Rnw'

###################################################
### code chunk number 1: affyPara.Rnw:58-59
###################################################
library(affyPara)


###################################################
### code chunk number 2: affyPara.Rnw:116-117
###################################################
library(affyPara)


###################################################
### code chunk number 3: affyPara.Rnw:121-124
###################################################
library(affydata)
data(Dilution)
Dilution


###################################################
### code chunk number 4: affyPara.Rnw:138-139
###################################################
cl <- makeCluster(4, type='SOCK')


###################################################
### code chunk number 5: affyPara.Rnw:146-147
###################################################
stopCluster(cl)


###################################################
### code chunk number 6: affyPara.Rnw:149-150
###################################################
cl <- makeCluster(2, type='SOCK')


###################################################
### code chunk number 7: affyPara.Rnw:176-177 (eval = FALSE)
###################################################
## AffyBatch <- ReadAffy()


###################################################
### code chunk number 8: affyPara.Rnw:210-211
###################################################
bgcorrect.methods()


###################################################
### code chunk number 9: affyBatchBGC
###################################################
affyBatchBGC <- bgCorrectPara(Dilution,
				method="rma", verbose=TRUE)


###################################################
### code chunk number 10: affyBatchBGCfiles (eval = FALSE)
###################################################
## files <- list.celfiles(full.names=TRUE)
## affyBatchGBC <- bgCorrectPara(files, 
## 				method="rma", cluster=cl)


###################################################
### code chunk number 11: affyBatchNORM
###################################################
affyBatchNORM <- normalizeAffyBatchQuantilesPara(
		Dilution, type = "pmonly", verbose=TRUE)


###################################################
### code chunk number 12: affyBatchGBCfiles (eval = FALSE)
###################################################
## files <- list.celfiles(full.names=TRUE)
## affyBatchNORM <- normalizeAffyBatchQuantilesPara(
## 		files, type = "pmonly")


###################################################
### code chunk number 13: affyPara.Rnw:289-291
###################################################
express.summary.stat.methods()
pmcorrect.methods()


###################################################
### code chunk number 14: computeExprSetPara (eval = FALSE)
###################################################
## esset <- computeExprSetPara(
## 	Dilution,
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### code chunk number 15: computeExprSetParafiles (eval = FALSE)
###################################################
## files <- list.celfiles(full.names=TRUE)
## esset <- normalizeAffyBatchQuantilesPara(
## 	files, 
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### code chunk number 16: preproPara (eval = FALSE)
###################################################
## esset <- preproPara(
## 	Dilution, 
## 	bgcorrect = TRUE, bgcorrect.method = "rma",
## 	normalize = TRUE, normalize.method = "quantil",
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### code chunk number 17: preproParafiles (eval = FALSE)
###################################################
## files <- list.celfiles(full.names=TRUE)
## esset <- preproPara(
## 	files, 
## 	bgcorrect = TRUE, bgcorrect.method = "rma",
## 	normalize = TRUE, normalize.method = "quantil",
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### code chunk number 18: rmaPara (eval = FALSE)
###################################################
## esset <- rmaPara(Dilution)


###################################################
### code chunk number 19: rmaParaFiles (eval = FALSE)
###################################################
## files <- list.celfiles(full.names=TRUE)
## esset <- rmaPara(files)


###################################################
### code chunk number 20: qc (eval = FALSE)
###################################################
## boxplotPara(Dilution)
## MAplotPara(Dilution)


###################################################
### code chunk number 21: distributeFiles (eval = FALSE)
###################################################
## path <- "tmp/CELfiles" # path at local computer system (master)
## files <- list.files(path,full.names=TRUE)
## distList <- distributeFiles(CELfiles, protocol="RCP")
## eset <- rmaPara(distList$CELfiles)


###################################################
### code chunk number 22: removeDistributedFiles (eval = FALSE)
###################################################
## removeDistributedFiles("/usr1/tmp/CELfiles")


###################################################
### code chunk number 23: identical_bgc
###################################################
affybatch1 <- bg.correct(Dilution,
		method="rma") 
 affybatch2 <- bgCorrectPara(Dilution,
		method="rma")
identical(exprs(affybatch1),exprs(affybatch2))
all.equal(exprs(affybatch1),exprs(affybatch2))


###################################################
### code chunk number 24: identical_loess (eval = FALSE)
###################################################
## set.seed(1234)
## affybatch1 <- normalize.AffyBatch.loess(Dilution)
## set.seed(1234)
## affybatch2 <- normalizeAffyBatchLoessPara(Dilution, verbose=TRUE) 
## identical(exprs(affybatch1),exprs(affybatch2))


###################################################
### code chunk number 25: affyPara.Rnw:504-505
###################################################
stopCluster()
